@@ -67,14 +67,19 @@ class EvalExample:
 
 @datasets.utils.file_utils.add_start_docstrings(_DESCRIPTION, _KWARGS_DESCRIPTION)
 class MaxCharMatch(datasets.Metric):
-    def __init__(self, tokenizer, *args, **kwargs):
+    def __init__(self, tokenizer=None, debug=False, *args, **kwargs):
         super(MaxCharMatch, self).__init__(*args, **kwargs)
         self.sa = SpellAlignment()
         self.save = False
+        
         self.tokenizer = tokenizer
+        if not self.tokenizer:
+            print("Tokenizer is None, convert_to_text won't be available!")
+
         self.batch_size = 16
         self.origs = []
         self.cors = []
+        self.debug = debug
 
     @staticmethod
     def normalize_sentence(sent: str) -> str:
@@ -82,12 +87,15 @@ class MaxCharMatch(datasets.Metric):
         return sent.translate(str.maketrans("", "", string.punctuation))
 
     def convert_to_text(self, inputs) -> List[str]:
+        if not self.tokenizer:
+            raise Exception("Tokenizer is not defined, reinitialize the class and pass a tokenizer.")
+
         text = []
         num_batches = int(len(inputs) / self.batch_size)
         for chunk in tqdm(chunked(inputs, self.batch_size), total=num_batches):
             text += self.tokenizer.batch_decode(
                 chunk,
-                skip_special_tokens=True
+                skip_special_tokens=True,
                 clean_up_tokenization_spaces=True,
             )
         return text
@@ -175,6 +183,11 @@ class MaxCharMatch(datasets.Metric):
             fn_agg += fn
 
             if f_out:
+                if self.debug:
+                    f_out.write("orig: " + o + "<br>\n")
+                    f_out.write("cor: " + c + "<br>\n")
+                    f_out.write("pred: " + p + "<br>\n")
+
                 f_out.write(self.get_html_diff(o, c) + "<br>\n")
                 f_out.write(self.get_html_diff(o, p) + "<br><br>\n\n")
         if self.save:
